==> maDB_1.12.0.tar.gz: maDB/R/geneRanking.R <==
## file ok, last checked: 03.05.2007

.getCName <- function(x){
	result <- c(paste(x[1],"up"),paste(x[1],"down"),paste(x[1],"all"))
	result
}

##
# if no.mapping.to.ug the ids are not condensed to UniGene. count.cols=list(c("6h","8h"),"24h") counts the probe sets regulated in the comparisons with
# samples that have "6h" and "8h" entries in the search.column , and counts those that are regulated in the "24h" samples
dbGetGeneRegulationRanking <- function(con,ug=NULL,id=NULL,include.by.name=NULL,exclude.by.name=NULL,include.by.pk=NULL,exclude.by.pk=NULL,count.cols=NULL,write.info.file=TRUE,search.column="exposure_time",no.mapping.to.ug=FALSE,m.up=1,m.down=-1,v=TRUE,chip=NULL){
	require(pgUtils)
	if(is.null(chip)){
		stop("Please submit the chip (if you are using the hgu133plus2 chip from Affymetrix and you have inserted the annotation into the annotation table submit hgu133plus2).")
	}
	info <- dbGetResult(dbSendQuery(con,"SELECT * FROM comparisons JOIN signal_channels ON (r_signal_channel=signal_channels_pk) JOIN samples ON (samples_fk=samples_pk)"))
	
	info <- .reduceInfo(info,include.by.name=include.by.name,include.by.pk=include.by.pk,exclude.by.name=exclude.by.name,exclude.by.pk=exclude.by.pk,pk.col="comparisons_pk",order=TRUE)
	
	


	
	## split mouse and human comparisons
	hs.info <- info[info[,"species"]=="hs",]
	mm.info <- info[info[,"species"]=="mm",]
	cat("Rank genes using the following comparisons:\n")
	for(i in 1:length(info[,1])){
		cat(paste(info[i,"name"],info[i,"tissue"],info[i,"exposure_time"],info[i,"description"],"\n"))
	}
	datum <- date()
	if(write.info.file){
		write.table(info,file=paste("HL",datum,"Info.txt",sep=""),sep="\t")
	}
	
	
	a.id <- c()
	if(no.mapping.to.ug){
		a.id <- id
	}
	else{
		if(!is.null(id)){
			ann <- getDBAnnotation(con,id=id,chip=chip,quickload=TRUE)
			ug <- unique(c(ug,ann[,"uni_gene"]))
			ug <- ug[ug!=""]
		
			## the a.id are ids that can not be annotated to unigene ids...
			a.id <- ann[ann[,"uni_gene"]=="","id"]
		}
	
		if(is.null(id) & is.null(ug)){
			ug <- dbGetResult(dbSendQuery(con,"SELECT DISTINCT uni_gene FROM annotation WHERE chip='hgu133plus2'"))[,1]
			ug <- ug[ug!=""]
		}
	}
	
	
	result.table <- matrix(ncol=(6+3*length(count.cols)),nrow=(length(ug)+length(a.id)))
	result.table[,4] <- 0
	result.table[,5] <- 0
	result.table[,6] <- 0
	
	colnames(result.table) <- c("UniGene","Description","Name","nr.up","nr.down","nr.overall",unlist(lapply(count.cols,.getCName)))
	up.counter <- NULL
	down.counter <- NULL
	
	##
	# working with the genes....
	if(length(ug>0)){
		if(v){
			progress(0,steps=40)
		}
	for(i in 1:length(ug)){
		result.table[i,"UniGene"] <- ug[i]
		res <- dbSendQuery(con,"SELECT * FROM (SELECT id,m,a,comparisons_fk,name,tissue,treatment,exposure_time FROM (SELECT id,m,a,comparisons_fk FROM regulation_values WHERE m>",rpgsql.format.values(m.up),"OR m<",rpgsql.format.values(m.down),") AS reg JOIN comparisons ON (comparisons_fk=comparisons_pk) JOIN signal_channels ON (r_signal_channel=signal_channels_pk) JOIN samples ON (samples_fk=samples_pk)) AS ttt JOIN (SELECT id,uni_gene,description,symbol FROM annotation WHERE uni_gene=",rpgsql.format.values(ug[i]),") AS tt ON (ttt.id=tt.id)")
		m <- dbGetResult(res)
		if(nrow(m)>0){
			up.counter <- 0
			down.counter <- 0
			result.table[i,"Description"] <- m[1,"description"]
			#cat(result.table[i,"Description"],"\n")
			result.table[i,"Name"] <- m[1,"symbol"]
			for(j in 1:length(info[,1])){
				#m.t <- m[myGrep(m[,"comparisons_fk"],pattern=info[j,"comparisons_pk"],exact.match=TRUE),]
				#write.table(m.t,file=paste("Test",j,k,".txt",sep=""),sep="\t")
				#m.vals <- m.t[,"m"]
				m.vals <- m[myGrep(m[,"comparisons_fk"],pattern=info[j,"comparisons_pk"],exact.match=TRUE),"m"]
				if(length(m.vals>0)){
					up.counter <- up.counter + max(as.numeric(m.vals) > m.up,na.rm=TRUE)
					down.counter <- down.counter + max(as.numeric(m.vals) < m.down,na.rm=TRUE)
				}
			}
			result.table[i,"nr.up"] <- up.counter
			result.table[i,"nr.down"] <- down.counter
			result.table[i,"nr.overall"] <- up.counter + down.counter
			if(length(count.cols)>0){
				for(k in 1:length(count.cols)){
					up.counter <- 0
					down.counter <- 0
					for(j in 1:length(info[,1])){
						m.t <- m[myGrep(m[,"comparisons_fk"],pattern=info[j,"comparisons_pk"],exact.match=TRUE),]
						#write.table(m.t,file=paste("test/Test",i,".",j,".",k,".txt",sep=""),sep="\t")
						m.vals <- m.t[multiGrep(m.t[,search.column],pattern=count.cols[[k]],exact.match=TRUE),"m"]
						#write.table(m.vals,file=paste("test/M.vals",i,".",j,".",k,".txt",sep=""),sep="\t")
						if(length(m.vals>0)){
							up.counter <- up.counter + max(as.numeric(m.vals) > m.up,na.rm=TRUE)
							down.counter <- down.counter + max(as.numeric(m.vals) < m.down,na.rm=TRUE)
						}
					}
					result.table[i,paste(count.cols[[k]][1],"up")] <- up.counter
					result.table[i,paste(count.cols[[k]][1],"down")] <- down.counter
					result.table[i,paste(count.cols[[k]][1],"all")] <- up.counter + down.counter
				}
			}
		}
		if(v){
			progress(i*100/length(ug),steps=40)
		}
	}
	if(v){
		progress(100,steps=40)
		cat("\nfinished\n")
	}
	}
	if(length(a.id)>0){
		if(v){
			cat("there are some ids left...\n")
			progress(0,steps=40)
		}
		for(i in 1:length(a.id)){
			res <- dbSendQuery(con,"SELECT * FROM (SELECT * FROM regulation_values WHERE id=",rpgsql.format.values(a.id[i]),") AS reg JOIN comparisons ON (comparisons_fk=comparisons_pk) JOIN signal_channels ON (r_signal_channel=signal_channels_pk) JOIN samples ON (samples_fk=samples_pk)")
		result.table[(i+length(ug)),"UniGene"] <- a.id[i]
		m <- dbGetResult(res)
		#write.table(m,file=paste(a.id[i],"m.txt",sep=""),sep="\t")
		if(nrow(m)>0){
			up.counter <- 0
			down.counter <- 0
			for(j in 1:length(info[,1])){
				m.vals <- m[myGrep(m[,"comparisons_fk"],pattern=info[j,"comparisons_pk"],exact.match=TRUE),"m"]
				#write.table(m.vals,file="AAAAAAA",sep="\t")
				if(length(m.vals>0)){
					up.counter <- up.counter + max(as.numeric(m.vals) > m.up,na.rm=TRUE)
					down.counter <- down.counter + max(as.numeric(m.vals) < m.down,na.rm=TRUE)
				}
			}
			result.table[(i+length(ug)),"nr.up"] <- up.counter
			result.table[(i+length(ug)),"nr.down"] <- down.counter
			result.table[(i+length(ug)),"nr.overall"] <- up.counter + down.counter
			if(length(count.cols)>0){
				for(k in 1:length(count.cols)){
					up.counter <- 0
					down.counter <- 0
					for(j in 1:length(info[,1])){
						m.t <- m[myGrep(m[,"comparisons_fk"],pattern=info[j,"comparisons_pk"],exact.match=TRUE),]
						#write.table(m.t,file=paste("test/Test",i,".",j,".",k,".txt",sep=""),sep="\t")
						m.vals <- m.t[multiGrep(m.t[,search.column],pattern=count.cols[[k]],exact.match=TRUE),"m"]
						#write.table(m.vals,file=paste("test/M.vals",i,".",j,".",k,".txt",sep=""),sep="\t")
						if(length(m.vals>0)){
							up.counter <- up.counter + max(as.numeric(m.vals) > m.up,na.rm=TRUE)
							down.counter <- down.counter + max(as.numeric(m.vals) < m.down,na.rm=TRUE)
						}
					}
					result.table[(i+length(ug)),paste(count.cols[[k]][1],"up")] <- up.counter
					result.table[(i+length(ug)),paste(count.cols[[k]][1],"down")] <- down.counter
					result.table[(i+length(ug)),paste(count.cols[[k]][1],"all")] <- up.counter + down.counter
				}
			}
		}
		if(v){
			progress(i*100/length(a.id),steps=40)
		}
		}
		if(v){
			progress(100,steps=40)
			cat("\nfinished\n")
		}
	}
	
	#idx <- order(result.table[,"nr.overall"],decreasing=TRUE)
	#result.table <- result.table[idx,]
#	if(write.file){
#		write.table(result.table,file=paste(label,)
#	}
	
	result.table
	
}

==> maDB_1.20.0.tar.gz: maDB/R/geneRanking.R <==
## file ok, last checked: 03.05.2007

.getCName <- function(x){
	result <- c(paste(x[1],"up"),paste(x[1],"down"),paste(x[1],"all"))
	result
}

##
# if no.mapping.to.ug the ids are not condensed to UniGene. count.cols=list(c("6h","8h"),"24h") counts the probe sets regulated in the comparisons with
# samples that have "6h" and "8h" entries in the search.column , and counts those that are regulated in the "24h" samples
dbGetGeneRegulationRanking <- function(con,ug=NULL,id=NULL,include.by.name=NULL,exclude.by.name=NULL,include.by.pk=NULL,exclude.by.pk=NULL,count.cols=NULL,write.info.file=TRUE,search.column="exposure_time",no.mapping.to.ug=FALSE,m.up=1,m.down=-1,v=TRUE,chip=NULL){
	require(pgUtils)
	if(is.null(chip)){
		stop("Please submit the chip (if you are using the hgu133plus2 chip from Affymetrix and you have inserted the annotation into the annotation table submit hgu133plus2).")
	}
	info <- dbGetResult(dbSendQuery(con,"SELECT * FROM comparisons JOIN signal_channels ON (r_signal_channel=signal_channels_pk) JOIN samples ON (samples_fk=samples_pk)"))
	
	info <- .reduceInfo(info,include.by.name=include.by.name,include.by.pk=include.by.pk,exclude.by.name=exclude.by.name,exclude.by.pk=exclude.by.pk,pk.col="comparisons_pk",order=TRUE)
	
	


	
	## split mouse and human comparisons
	hs.info <- info[info[,"species"]=="hs",]
	mm.info <- info[info[,"species"]=="mm",]
	cat("Rank genes using the following comparisons:\n")
	for(i in 1:length(info[,1])){
		cat(paste(info[i,"name"],info[i,"tissue"],info[i,"exposure_time"],info[i,"description"],"\n"))
	}
	datum <- date()
	if(write.info.file){
		write.table(info,file=paste("HL",datum,"Info.txt",sep=""),sep="\t")
	}
	
	
	a.id <- c()
	if(no.mapping.to.ug){
		a.id <- id
	}
	else{
		if(!is.null(id)){
			ann <- dbGetAnnotation(con,id=id,chip=chip,quickload=TRUE)
			ug <- unique(c(ug,ann[,"uni_gene"]))
			ug <- ug[ug!=""]
		
			## the a.id are ids that can not be annotated to unigene ids...
			a.id <- ann[ann[,"uni_gene"]=="","id"]
		}
	
		if(is.null(id) & is.null(ug)){
			ug <- dbGetResult(dbSendQuery(con,"SELECT DISTINCT uni_gene FROM annotation WHERE chip='hgu133plus2'"))[,1]
			ug <- ug[ug!=""]
		}
	}
	
	
	result.table <- matrix(ncol=(6+3*length(count.cols)),nrow=(length(ug)+length(a.id)))
	result.table[,4] <- 0
	result.table[,5] <- 0
	result.table[,6] <- 0
	
	colnames(result.table) <- c("UniGene","Description","Name","nr.up","nr.down","nr.overall",unlist(lapply(count.cols,.getCName)))
	up.counter <- NULL
	down.counter <- NULL
	
	##
	# working with the genes....
	if(length(ug>0)){
		if(v){
			progress(0,steps=40)
		}
	for(i in 1:length(ug)){
		result.table[i,"UniGene"] <- ug[i]
		res <- dbSendQuery(con,"SELECT * FROM (SELECT id,m,a,comparisons_fk,name,tissue,treatment,exposure_time FROM (SELECT id,m,a,comparisons_fk FROM regulation_values WHERE m>",rpgsql.format.values(m.up),"OR m<",rpgsql.format.values(m.down),") AS reg JOIN comparisons ON (comparisons_fk=comparisons_pk) JOIN signal_channels ON (r_signal_channel=signal_channels_pk) JOIN samples ON (samples_fk=samples_pk)) AS ttt JOIN (SELECT id,uni_gene,description,symbol FROM annotation WHERE uni_gene=",rpgsql.format.values(ug[i]),") AS tt ON (ttt.id=tt.id)")
		m <- dbGetResult(res)
		if(nrow(m)>0){
			up.counter <- 0
			down.counter <- 0
			result.table[i,"Description"] <- m[1,"description"]
			#cat(result.table[i,"Description"],"\n")
			result.table[i,"Name"] <- m[1,"symbol"]
			for(j in 1:length(info[,1])){
				#m.t <- m[myGrep(m[,"comparisons_fk"],pattern=info[j,"comparisons_pk"],exact.match=TRUE),]
				#write.table(m.t,file=paste("Test",j,k,".txt",sep=""),sep="\t")
				#m.vals <- m.t[,"m"]
				m.vals <- m[myGrep(m[,"comparisons_fk"],pattern=info[j,"comparisons_pk"],exact.match=TRUE),"m"]
				if(length(m.vals>0)){
					up.counter <- up.counter + max(as.numeric(m.vals) > m.up,na.rm=TRUE)
					down.counter <- down.counter + max(as.numeric(m.vals) < m.down,na.rm=TRUE)
				}
			}
			result.table[i,"nr.up"] <- up.counter
			result.table[i,"nr.down"] <- down.counter
			result.table[i,"nr.overall"] <- up.counter + down.counter
			if(length(count.cols)>0){
				for(k in 1:length(count.cols)){
					up.counter <- 0
					down.counter <- 0
					for(j in 1:length(info[,1])){
						m.t <- m[myGrep(m[,"comparisons_fk"],pattern=info[j,"comparisons_pk"],exact.match=TRUE),]
						#write.table(m.t,file=paste("test/Test",i,".",j,".",k,".txt",sep=""),sep="\t")
						m.vals <- m.t[multiGrep(m.t[,search.column],pattern=count.cols[[k]],exact.match=TRUE),"m"]
						#write.table(m.vals,file=paste("test/M.vals",i,".",j,".",k,".txt",sep=""),sep="\t")
						if(length(m.vals>0)){
							up.counter <- up.counter + max(as.numeric(m.vals) > m.up,na.rm=TRUE)
							down.counter <- down.counter + max(as.numeric(m.vals) < m.down,na.rm=TRUE)
						}
					}
					result.table[i,paste(count.cols[[k]][1],"up")] <- up.counter
					result.table[i,paste(count.cols[[k]][1],"down")] <- down.counter
					result.table[i,paste(count.cols[[k]][1],"all")] <- up.counter + down.counter
				}
			}
		}
		if(v){
			progress(i*100/length(ug),steps=40)
		}
	}
	if(v){
		progress(100,steps=40)
		cat("\nfinished\n")
	}
	}
	if(length(a.id)>0){
		if(v){
			cat("there are some ids left...\n")
			progress(0,steps=40)
		}
		for(i in 1:length(a.id)){
			res <- dbSendQuery(con,"SELECT * FROM (SELECT * FROM regulation_values WHERE id=",rpgsql.format.values(a.id[i]),") AS reg JOIN comparisons ON (comparisons_fk=comparisons_pk) JOIN signal_channels ON (r_signal_channel=signal_channels_pk) JOIN samples ON (samples_fk=samples_pk)")
		result.table[(i+length(ug)),"UniGene"] <- a.id[i]
		m <- dbGetResult(res)
		#write.table(m,file=paste(a.id[i],"m.txt",sep=""),sep="\t")
		if(nrow(m)>0){
			up.counter <- 0
			down.counter <- 0
			for(j in 1:length(info[,1])){
				m.vals <- m[myGrep(m[,"comparisons_fk"],pattern=info[j,"comparisons_pk"],exact.match=TRUE),"m"]
				#write.table(m.vals,file="AAAAAAA",sep="\t")
				if(length(m.vals>0)){
					up.counter <- up.counter + max(as.numeric(m.vals) > m.up,na.rm=TRUE)
					down.counter <- down.counter + max(as.numeric(m.vals) < m.down,na.rm=TRUE)
				}
			}
			result.table[(i+length(ug)),"nr.up"] <- up.counter
			result.table[(i+length(ug)),"nr.down"] <- down.counter
			result.table[(i+length(ug)),"nr.overall"] <- up.counter + down.counter
			if(length(count.cols)>0){
				for(k in 1:length(count.cols)){
					up.counter <- 0
					down.counter <- 0
					for(j in 1:length(info[,1])){
						m.t <- m[myGrep(m[,"comparisons_fk"],pattern=info[j,"comparisons_pk"],exact.match=TRUE),]
						#write.table(m.t,file=paste("test/Test",i,".",j,".",k,".txt",sep=""),sep="\t")
						m.vals <- m.t[multiGrep(m.t[,search.column],pattern=count.cols[[k]],exact.match=TRUE),"m"]
						#write.table(m.vals,file=paste("test/M.vals",i,".",j,".",k,".txt",sep=""),sep="\t")
						if(length(m.vals>0)){
							up.counter <- up.counter + max(as.numeric(m.vals) > m.up,na.rm=TRUE)
							down.counter <- down.counter + max(as.numeric(m.vals) < m.down,na.rm=TRUE)
						}
					}
					result.table[(i+length(ug)),paste(count.cols[[k]][1],"up")] <- up.counter
					result.table[(i+length(ug)),paste(count.cols[[k]][1],"down")] <- down.counter
					result.table[(i+length(ug)),paste(count.cols[[k]][1],"all")] <- up.counter + down.counter
				}
			}
		}
		if(v){
			progress(i*100/length(a.id),steps=40)
		}
		}
		if(v){
			progress(100,steps=40)
			cat("\nfinished\n")
		}
	}
	
	#idx <- order(result.table[,"nr.overall"],decreasing=TRUE)
	#result.table <- result.table[idx,]
#	if(write.file){
#		write.table(result.table,file=paste(label,)
#	}
	
	result.table
	
}
